<?php
/**
 * onepagelover functions and definitions.
 *
 * @link https://codex.wordpress.org/Functions_File_Explained
 *
 * @package Awesome One Page
 */

if ( ! function_exists( 'awesome_one_page_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function awesome_one_page_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on onepagelover, use a find and replace
	 * to change 'awesome-one-page' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'awesome-one-page', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );


	// Add default posts and comments RSS feed links to head.
	//add_theme_support( 'automatic-feed-links' );

	// Remove Emoji
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'wp_print_styles', 'print_emoji_styles' );

	// Remove Weblog Client Link
	remove_action ('wp_head', 'rsd_link');

	// Windows Live Writer Manifest Link
	remove_action( 'wp_head', 'wlwmanifest_link');

	//WordPress Generator (with version information)
	remove_action('wp_head', 'wp_generator');

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/**
	 * Add editor style
	 */
	add_editor_style( 'css/custom-editor-style.css' );


	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'awesome-one-page' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'awesome_one_page_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // awesome_one_page_setup
add_action( 'after_setup_theme', 'awesome_one_page_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function awesome_one_page_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'awesome_one_page_content_width', 640 );
}
add_action( 'after_setup_theme', 'awesome_one_page_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function awesome_one_page_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Front Newsletter form', 'awesome-one-page' ),
		'id'            => 'front-newsletter',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'awesome_one_page_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function awesome_one_page_scripts() {

	wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/css/bootstrap.min.css', 'all' );

	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/css/font-awesome.min.css', 'all' );

	wp_enqueue_style( 'animate-css', get_template_directory_uri() . '/css/animate.min.css', 'all' );

	wp_enqueue_style( 'swiper-css', get_template_directory_uri() . '/css/swiper.min.css', 'all' );

	wp_enqueue_style( 'onepagelover-style', get_stylesheet_uri() );

	wp_enqueue_script( 'jquery.library', get_template_directory_uri() . '/js/jquery-2.1.4.min.js', array(), '', '' );

	wp_enqueue_script( 'jquery.wow', get_template_directory_uri() . '/js/wow.min.js', array(), '', '' );

	wp_enqueue_script( 'smooth-speed', get_template_directory_uri() . '/js/jquery.scrollSpeed.min.js', array(), '', 'true' );

	wp_enqueue_script( 'jquery.swiper', get_template_directory_uri() . '/js/swiper.jquery.min.js', array(), '', true );

	wp_enqueue_script( 'custom-js', get_template_directory_uri() . '/js/custom.js', array(), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'awesome_one_page_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Woocommerce support
 */
add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
	add_theme_support( 'woocommerce' );
}

/**
 * Woocommerce redirect to checkout page
 */
add_filter ('add_to_cart_redirect', 'redirect_to_checkout');

function redirect_to_checkout() {
	global $woocommerce;
	$checkout_url = $woocommerce->cart->get_checkout_url();
	return $checkout_url;
}

/**
 * Woocommerce remove additional info
 */
add_filter('woocommerce_enable_order_notes_field', '__return_false');